@@ -34,7 +34,7 @@ list_volume_excerpts <-
       }
       rq <- databraryr::make_default_request()
     }
-    rq <- rq |>
+    rq <- rq %>%
       httr2::req_url(sprintf(GET_VOLUME_EXCERPTS, vol_id))
     
     resp <- tryCatch(
