@@ -29,7 +29,7 @@ list_volume_links <- function(vol_id = 1,
     }
     rq <- databraryr::make_default_request()
   }
-  rq <- rq |>
+  rq <- rq %>%
     httr2::req_url(sprintf(GET_VOLUME_LINKS, vol_id))
   
   resp <- tryCatch(
@@ -43,9 +43,9 @@ list_volume_links <- function(vol_id = 1,
   if (!is.null(resp)) {
     res <- httr2::resp_body_json(resp)
     if (!(is.null(res$links))) {
-      purrr::map(res$links, tibble::as_tibble) |>
-        purrr::list_rbind() |>
-        dplyr::rename(link_name = head, link_url = url) |>
+      purrr::map(res$links, tibble::as_tibble) %>%
+        purrr::list_rbind() %>%
+        dplyr::rename(link_name = head, link_url = url) %>%
         dplyr::mutate(vol_id = vol_id)
     }
   } else {
