@@ -1,6 +1,6 @@
 # search_for_tags() ---------------------------------------------------
 test_that("search_for_tags returns character", {
-  expect_true(class(search_for_tags()) == "character")
+  expect_true("character" %in% class(search_for_tags()))
 })
 
 test_that("search_for_tags rejects bad input parameters", {
@@ -13,4 +13,9 @@ test_that("search_for_tags rejects bad input parameters", {
   expect_error(search_for_tags(vb = 3))
   expect_error(search_for_tags(vb = "a"))
   expect_error(search_for_tags(vb = list(a=1, b=2)))
+  
+  expect_error(search_for_tags(rq = "a"))
+  expect_error(search_for_tags(rq = -1))
+  expect_error(search_for_tags(rq = c(2,3)))
+  expect_error(search_for_tags(rq = list(a=1, b=2)))
 })
